#! /usr/bin/env python
import os
from setuptools import setup
from finitelycomputable_microsites_setup import (
        version, base_setup, wsgi_extras_require, cherrypy_version,
)

with open(os.path.join(os.path.dirname(__file__), 'README.rst')) as readme:
    README = readme.read()

# allow setup.py to be run from any path
os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

setup(
    name='finitelycomputable-cherrypy-mount',
    version=version,
    py_modules=['finitelycomputable.cherrypy_mount'],
    entry_points={
        'console_scripts': [
            'finitelycomputable-cherrypy-mount = finitelycomputable.cherrypy_mount:run']
        },
    description='The CherryPy-based wsgi app using tree.mount()for the microsites of finitelycomputable.net',
    long_description=README,
    long_description_content_type="text/x-rst",
    scripts=['finitelycomputable_microsites_setup.py'],
    install_requires=[cherrypy_version],
    extras_require=wsgi_extras_require,
    url='http://www.finitelycomputable.net/wsgi_info',
    **base_setup
)



import cherrypy
from os import environ
from platform import python_version
from posixpath import join

from finitelycomputable_microsites_setup import version


version_text = environ.get('MICROSITES_VERSION_TEXT', '')
base_path = join('/', environ.get('BASE_PATH', ''))
included_apps = []

class WsgiInfo(object):
    @cherrypy.expose
    def index(self):
        return (
f'''{version_text} using {__name__} {version} on Python {python_version()}
at {base_path} with {', '.join(included_apps) or "nothing"}\n'''
    )

def setup_server():
    cherrypy.tree.mount(WsgiInfo(), join(base_path, 'wsgi_info/'), {'/': {}})
    try:
        from finitelycomputable.helloworld_cherrypy import HelloWorld
        cherrypy.tree.mount(
                HelloWorld(), join(base_path,'hello_world/'), {'/': {}})
        included_apps.append('helloworld_cherrypy')
    except ModuleNotFoundError:
        pass
    return cherrypy.tree


application = setup_server()


def run():
    from sys import argv, exit, stderr
    if len(argv) < 2 or argv[1] != 'run':
        stderr.write(f'usage: {argv[0]} run [port]\n')
        exit(1)
    try:
        cherrypy.config.update({'server.socket_port': int(argv[2])})
    except IndexError:
        pass
    cherrypy.engine.start()
    cherrypy.engine.block()
